// Written Dec 2011 Tom Horsley
// Released to the universe with no license restrictions of any kind.

#include "find-mkisofs.h"
#include <stdlib.h>
#include <unistd.h>
#include <string.h>

std::string FindMkisofs::mkisofs_prog = "/opt/schily/bin/mkisofs";

std::string FindMkisofs::mkisofs_args =
   "-quiet -volid TEST_IMAGE -volset '' "
   "-appid 'isopack test image' -publisher '' -preparer '' "
   "-sysid LINUX -volset-size 1 -volset-seqno 1 "
   "-rational-rock -joliet -joliet-long -no-cache-inodes "
   "-udf -full-iso9660-filenames -iso-level 3";

void
FindMkisofs::SetMkisofsProgram(std::string init_mkisofs_program) {
   mkisofs_prog = init_mkisofs_program;
}

bool
FindMkisofs::SearchPathForMkisofs() {
   const char * path = getenv("PATH");
   while (path != NULL) {
      const char * coln = strchr(path, ':');
      std::string dir;
      if (coln != NULL) {
         dir.append(path, coln-path);
         path = coln+1;
      } else {
         dir.append(path);
         path = NULL;
      }
      if (dir.size() > 0) {
         if (dir[dir.size()-1] != '/') {
            dir.append(1, '/');
         }
         dir.append("mkisofs");
         if (access(dir.c_str(), X_OK) == 0) {
            SetMkisofsProgram(dir);
            return true;
         }
      }
   }
   return false;
}

bool
FindMkisofs::ValidMkisofsProg() {
   return (access(mkisofs_prog.c_str(), X_OK) == 0);
}

void
FindMkisofs::SetMkisofsArguments(std::string init_arguments) {
   mkisofs_args = init_arguments;
}

std::string
FindMkisofs::GetMkisofsProgram() {
   return mkisofs_prog;
}

std::string
FindMkisofs::GetMkisofsArguments() {
   // Stick the mandatory args isopack needs in the string,
   // but allow others to be set by the user.

   std::string full_args("-print-size -graft-points ");
   full_args.append(GetPlainMkisofsArguments());
   full_args.append(" -path-list");
   return full_args;
}

std::string
FindMkisofs::GetPlainMkisofsArguments() {
   return mkisofs_args;
}
